@@ -7,7 +7,7 @@ use elbus::common::{BrokerInfo, BrokerStats, ClientList};
 use elbus::ipc::{Client, Config};
 use elbus::rpc::{DummyHandlers, Rpc, RpcClient, RpcError, RpcEvent, RpcHandlers, RpcResult};
 use elbus::{empty_payload, Error, Frame, QoS};
-use log::info;
+use log::{error, info};
 use num_format::{Locale, ToFormattedString};
 use serde_value::Value;
 use std::collections::BTreeMap;
@@ -73,7 +73,7 @@ struct RpcCall {
     target: String,
     #[clap()]
     method: String,
-    #[clap(help = "payload string key=value, empty for stdin payload or '_' for no params")]
+    #[clap(help = "payload string key=value, '-' for stdin payload")]
     params: Vec<String>,
 }
 
@@ -215,8 +215,8 @@ async fn print_payload(payload: &[u8], silent: bool) {
             print_hex(payload);
         }
     } else if silent {
-        let mut stdin = tokio::io::stdout();
-        stdin.write_all(payload).await.unwrap();
+        let mut stdout = tokio::io::stdout();
+        stdout.write_all(payload).await.unwrap();
     } else {
         print_hex(payload);
     }
@@ -530,7 +530,7 @@ async fn benchmark_rpc(
 }
 
 #[allow(clippy::too_many_lines)]
-#[tokio::main(worker_threads=1)]
+#[tokio::main(worker_threads = 1)]
 async fn main() {
     let opts = Opts::parse();
     let client_name = opts.name.as_ref().map_or_else(
@@ -563,15 +563,13 @@ async fn main() {
     macro_rules! prepare_rpc_call {
         ($c: expr, $client: expr) => {{
             let rpc = RpcClient::new($client, DummyHandlers {});
-            let payload = if $c.params.is_empty() {
+            let payload = if $c.params.len() == 1 && $c.params[0] == "-" {
                 read_stdin().await
+            } else if $c.params.is_empty() {
+                Vec::new()
             } else {
-                if $c.params.len() == 1 && $c.params[0] == "_" {
-                    Vec::new()
-                } else {
-                    let s = $c.params.iter().map(String::as_str).collect::<Vec<&str>>();
-                    rmp_serde::to_vec_named(&elbus::common::str_to_params_map(&s).unwrap()).unwrap()
-                }
+                let s = $c.params.iter().map(String::as_str).collect::<Vec<&str>>();
+                rmp_serde::to_vec_named(&elbus::common::str_to_params_map(&s).unwrap()).unwrap()
             };
             (rpc, payload)
         }};
@@ -725,11 +723,19 @@ async fn main() {
                 }
                 RpcCommand::Call(cmd) => {
                     let (rpc, payload) = prepare_rpc_call!(cmd, client);
-                    let result = rpc
+                    match rpc
                         .call(&cmd.target, &cmd.method, payload.into(), QoS::Processed)
                         .await
-                        .unwrap();
-                    print_payload(result.payload(), opts.silent).await;
+                    {
+                        Ok(result) => print_payload(result.payload(), opts.silent).await,
+                        Err(e) => {
+                            let message = e
+                                .data()
+                                .map_or("", |data| std::str::from_utf8(data).unwrap_or(""));
+                            error!("RPC Error {}: {}", e.code(), message);
+                            std::process::exit(1);
+                        }
+                    }
                 }
             }
         }
